from setuptools import setup

setup(name='dist_lulik',
      version='0.0',
      description='мій проект',
      packages=['dist_lulik'],
      author_email='lulik1988@gmail.com',
      zip_safe=False)
